import {
  getVueVersion
} from "./chunk-WFHZXRYC.mjs";

// src/index.ts
import { createCombinePlugin } from "unplugin-combine";
import VueDefineModel from "@vue-macros/define-model";
import VueDefineOptions from "unplugin-vue-define-options";
import VueDefineRender from "@vue-macros/define-render";
import VueHoistStatic from "@vue-macros/hoist-static";
import VueSetupComponent from "@vue-macros/setup-component";
import VueSetupSFC from "@vue-macros/setup-sfc";
import VueShortEmits from "@vue-macros/short-emits";
function resolveOptions({
  root,
  version,
  plugins,
  defineModel,
  defineOptions,
  defineRender,
  hoistStatic,
  setupComponent,
  setupSFC,
  shortEmits
}) {
  function resolveSubOptions(options, commonOptions = {}) {
    if (options === false)
      return false;
    else if (options === true || options === void 0)
      return { ...commonOptions };
    else
      return { ...options, ...commonOptions };
  }
  return {
    root: root || process.cwd(),
    version: version || getVueVersion(),
    plugins: plugins || {},
    defineModel: resolveSubOptions(defineModel, { version }),
    defineOptions: resolveSubOptions(defineOptions),
    defineRender: resolveSubOptions(defineRender),
    hoistStatic: resolveSubOptions(hoistStatic),
    setupComponent: resolveSubOptions(setupComponent, {
      root
    }),
    setupSFC: resolveSubOptions(setupSFC),
    shortEmits: resolveSubOptions(shortEmits)
  };
}
function resolvePlugin(options, unplugin) {
  if (!options)
    return;
  return [unplugin, options];
}
var name = "unplugin-vue-macros";
var src_default = createCombinePlugin((userOptions = {}) => {
  const options = resolveOptions(userOptions);
  const plugins = [
    resolvePlugin(options.setupSFC, VueSetupSFC),
    resolvePlugin(options.setupComponent, VueSetupComponent),
    resolvePlugin(options.hoistStatic, VueHoistStatic),
    resolvePlugin(options.shortEmits, VueShortEmits),
    resolvePlugin(options.defineOptions, VueDefineOptions),
    resolvePlugin(options.defineModel, VueDefineModel),
    options.plugins.vue,
    options.plugins.vueJsx,
    resolvePlugin(options.defineRender, VueDefineRender)
  ].filter(Boolean);
  return {
    name,
    plugins
  };
});

export {
  src_default
};
